package com.develou.p3_configuracion.ui

import android.app.Notification
import android.app.NotificationManager
import android.app.PendingIntent
import android.content.Intent
import android.graphics.BitmapFactory
import android.os.Bundle
import android.widget.Button
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import androidx.core.app.NotificationCompat
import androidx.core.app.NotificationManagerCompat
import androidx.core.app.TaskStackBuilder
import androidx.core.os.bundleOf
import com.develou.p3_configuracion.R
import com.develou.p3_configuracion.data.BookmarksStore
import com.develou.p3_configuracion.receiver.BookmarkReceiver
import com.develou.p3_configuracion.util.NotificationUtil
import com.develou.p3_configuracion.util.NotificationUtil.CHANNEL_ID

const val GROUP_ID = 100

class MainActivity : AppCompatActivity() {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        findViewById<Button>(R.id.notification_button).setOnClickListener {
            generateNotification(
                1,
                "1. Crear notificaciones",
                getString(R.string.post_big_text)
            )
        }

        NotificationUtil.createChannel(
            this,
            NotificationManager.IMPORTANCE_DEFAULT,
            getString(R.string.basic_channel_name),
            getString(R.string.basic_channel_description)
        )
    }

    override fun onWindowFocusChanged(hasFocus: Boolean) {
        if (hasFocus) {
            findViewById<TextView>(R.id.bookmarks_text).apply {
                text = getString(R.string.bookmarks, BookmarksStore.bookmarks)
            }
        }
    }

    private fun generateNotification(
        notificationId: Int,
        title: String,
        description: String
    ) {
        val largeIcon = BitmapFactory.decodeResource(
            resources,
            R.drawable.develou
        )

        val contentIntent = Intent(this, PostDetailActivity::class.java).apply {
            putExtras(
                bundleOf(
                    "notification_id" to notificationId,
                    "title" to title,
                    "body" to description
                )
            )
        }
        val contentPendingIntent: PendingIntent? = TaskStackBuilder.create(this).run {
            addNextIntentWithParentStack(contentIntent)
            getPendingIntent(0, PendingIntent.FLAG_UPDATE_CURRENT)
        }

        val style = NotificationCompat.BigTextStyle().bigText(description)

        val bookmarkIntent = Intent(applicationContext, BookmarkReceiver::class.java).apply {
            putExtra("notification_id", notificationId)
        }
        val bookmarkPendingIntent = PendingIntent.getBroadcast(
            applicationContext,
            notificationId,
            bookmarkIntent,
            PendingIntent.FLAG_UPDATE_CURRENT
        )

        val notification = NotificationCompat.Builder(this, CHANNEL_ID)
            .setLargeIcon(largeIcon)
            .setSmallIcon(R.drawable.ic_circle_notifications)
            .setContentTitle(title)
            .setContentText(description)
            .setSubText("Develou.com")
            .setStyle(style)
            .setContentIntent(contentPendingIntent)
            .setAutoCancel(true)
            .setPriority(NotificationCompat.PRIORITY_DEFAULT)
            .addAction(R.drawable.ic_bookmark, "Leer más tarde", bookmarkPendingIntent)
            .setVisibility(NotificationCompat.VISIBILITY_PRIVATE)
            .setPublicVersion(NotificationUtil.createPublicNotification(this))
            .setCategory(NotificationCompat.CATEGORY_RECOMMENDATION)
            .build()

        showNotification(notificationId, notification)
    }

    private fun showNotification(notificationId: Int, notification: Notification) {
        with(NotificationManagerCompat.from(this)) {
            notify(notificationId, notification)
        }
    }
}