package com.develou.p4_plantillas.ui

import android.app.NotificationManager
import android.os.Bundle
import android.view.View
import android.widget.AdapterView
import android.widget.ArrayAdapter
import android.widget.Button
import android.widget.Spinner
import androidx.appcompat.app.AppCompatActivity
import com.develou.p4_plantillas.R
import com.develou.p4_plantillas.util.NotificationUtil

class MainActivity : AppCompatActivity(), AdapterView.OnItemSelectedListener {

    private var selectedStylePosition: Int = 0

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        NotificationUtil.createChannel(
            this,
            NotificationManager.IMPORTANCE_DEFAULT,
            getString(R.string.basic_channel_name),
            getString(R.string.basic_channel_description)
        )

        setUpStyleMenu()
        setUpNotificationButton()
    }

    private fun setUpStyleMenu() {
        val styleMenu: Spinner = findViewById(R.id.style_menu)
        val styles = listOf(
            "Texto Largo",
            "Imagen Grande",
            "Controles Multimedia",
            "Bandeja De Entrada",
            "Conversación",
            "Progreso"
        )
        val adapter = ArrayAdapter(
            this,
            android.R.layout.simple_spinner_item,
            styles
        ).apply {
            setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item)
        }

        styleMenu.adapter = adapter
        styleMenu.onItemSelectedListener = this
    }

    private fun setUpNotificationButton() {
        findViewById<Button>(R.id.notification_button).setOnClickListener {
            onCreateNotificationButtonClick()
        }
    }

    private fun onCreateNotificationButtonClick(){
        when(selectedStylePosition){
            0-> NotificationUtil.createBigTextNotification(this)
            1->NotificationUtil.createBigPictureNotification(this)
            2->NotificationUtil.createMediaNotification(this)
            3->NotificationUtil.createInboxNotification(this)
            4->NotificationUtil.createMessagingNotification(this)
            5->NotificationUtil.createProgressNotification(this)
        }
    }

    override fun onItemSelected(parent: AdapterView<*>?, view: View?, position: Int, id: Long) {
        selectedStylePosition = position
    }

    override fun onNothingSelected(parent: AdapterView<*>?) {
        // No op.
    }
}