package com.develou.p4_plantillas.util

import android.app.Notification
import android.app.NotificationChannel
import android.app.NotificationManager
import android.content.Context
import android.graphics.BitmapFactory
import android.graphics.Color
import android.os.Build
import androidx.core.app.NotificationCompat
import androidx.core.app.NotificationManagerCompat
import androidx.core.app.Person
import com.develou.p4_plantillas.R
import java.util.*
import androidx.media.app.NotificationCompat as MediaNotificationCompat

object NotificationUtil {
    private val NOTIFICATION_ID: Int = 100
    private lateinit var CHANNEL_ID: String

    fun createChannel(
        context: Context,
        importance: Int,
        name: String,
        description: String
    ) {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            CHANNEL_ID = context.resources.getString(R.string.basic_channel_id)
            val channel = NotificationChannel(CHANNEL_ID, name, importance).apply {
                enableLights(true)
                enableVibration(true)
                this.description = description
                lightColor = Color.BLUE
                vibrationPattern = longArrayOf(0, 500, 500, 500, 500)
            }

            val nm: NotificationManager =
                context.getSystemService(Context.NOTIFICATION_SERVICE) as NotificationManager
            nm.createNotificationChannel(channel)
        }
    }

    fun createBigTextNotification(context: Context) {
        val resources = context.resources

        val title = "Plantillas Para Notificaciones"
        val description = resources.getString(R.string.post_big_text)
        val bigTextStyle = NotificationCompat.BigTextStyle() // (1)
            .setBigContentTitle(title) // (2)
            .setSummaryText("Android") // (3)
            .bigText(description) // (4)

        val notification = NotificationCompat.Builder(context, CHANNEL_ID)
            .setSmallIcon(R.drawable.ic_circle_notifications)
            .setContentTitle(title)
            .setContentText(description)
            .setStyle(bigTextStyle) // (5)
            .build()

        showNotification(context, notification)
    }

    fun createBigPictureNotification(context: Context) {
        val forestBitmap = BitmapFactory.decodeResource( // (1)
            context.resources,
            R.drawable.forest
        )
        val bigPictureStyle = NotificationCompat.BigPictureStyle() // (2)
            .bigPicture(forestBitmap) // (3)
            .bigLargeIcon(null) // (4)

        val notification = NotificationCompat.Builder(context, CHANNEL_ID)
            .setSmallIcon(R.drawable.ic_image_published)
            .setLargeIcon(forestBitmap) // (5)
            .setContentTitle("Miguel ha subido una foto")
            .setContentText("¡Hermoso!")
            .addAction(0, "Comentar", null)
            .setStyle(bigPictureStyle) // (6)
            .build()

        showNotification(context, notification)
    }

    fun createMediaNotification(context: Context) {
        val albumCoverBitmap = BitmapFactory.decodeResource( // (1)
            context.resources,
            R.drawable.album_cover
        )
        val mediaStyle = MediaNotificationCompat.MediaStyle() // (2)
            .setShowActionsInCompactView(1, 2, 3) // (3)

        val notification = NotificationCompat.Builder(context, CHANNEL_ID)
            .setVisibility(NotificationCompat.VISIBILITY_PUBLIC) // (4)
            .setSmallIcon(R.drawable.ic_music)
            .addAction(R.drawable.ic_thumb_down, "No me gusta", null) // (5)
            .addAction(R.drawable.ic_previous, "Anterior", null)
            .addAction(R.drawable.ic_pause, "Pausa", null)
            .addAction(R.drawable.ic_next, "Siguiente", null)
            .addAction(R.drawable.ic_thumb_up, "Me gusta", null)
            .setStyle(mediaStyle) // (6)
            .setContentTitle("Music Festival")
            .setContentText("01. Peace melody")
            .setLargeIcon(albumCoverBitmap) // (7)
            .build()

        showNotification(context, notification)
    }

    fun createInboxNotification(context: Context) {
        val inboxStyle = NotificationCompat.InboxStyle() // (1)
            .addLine("Maria12f:  ¿El USB es 3.0?") // (2)
            .addLine("FerM:  ¿Tienen unidades disponibles?")
            .addLine("Villegaz_a:  Necesito 30 unidades, ¿es posible?")
            .addLine("Albeiro83:  ¿En donde están ubicados?")

        val notification = NotificationCompat.Builder(context, CHANNEL_ID)
            .setSmallIcon(R.drawable.ic_new_questions)
            .setContentTitle("Tienes 4 preguntas sobre \"Mouse USB\"")
            .setContentText("Posibles clientes están esperándote")
            .setStyle(inboxStyle) // (3)
            .build()

        showNotification(context, notification)
    }

    fun createMessagingNotification(context: Context) {
        val fernanda = Person.Builder().setName("Fernanda Montes").build() // (1)
        val me = Person.Builder().setName("Yo").build()

        val message1 = NotificationCompat.MessagingStyle.Message( // (2)
            "Hola, recuerda que mañana es nuestra reunión",
            Calendar.getInstance().timeInMillis,
            fernanda
        )
        val message2 = NotificationCompat.MessagingStyle.Message(
            "Hola, vale",
            Calendar.getInstance().timeInMillis,
            me
        )
        val message3 = NotificationCompat.MessagingStyle.Message(
            "Asegúrate de traer tus documentos",
            Calendar.getInstance().timeInMillis,
            fernanda
        )

        val messagingStyle = NotificationCompat.MessagingStyle(me) // (3)
            .addMessage(message1)// (4)
            .addMessage(message2)
            .addMessage(message3)
        val notification = NotificationCompat.Builder(context, CHANNEL_ID)
            .setSmallIcon(R.drawable.ic_new_message)
            .setStyle(messagingStyle) // (5)
            .build()
        showNotification(context, notification)
    }

    fun createProgressNotification(context: Context) {
        val notification = NotificationCompat.Builder(context, CHANNEL_ID)
            .setSmallIcon(R.drawable.ic_devices)
            .setContentTitle("Buscando recursos")
            .setProgress(0, 0, true)
            .addAction(0, "Cancelar", null)
            .build()

        showNotification(context, notification)
    }

    private fun showNotification(context: Context, notification: Notification) {
        with(NotificationManagerCompat.from(context)) {
            notify(NOTIFICATION_ID, notification)
        }
    }
}
