package com.develou.p5_badges

import android.app.Notification
import android.app.NotificationChannel
import android.app.NotificationManager
import android.content.Context
import android.graphics.BitmapFactory
import android.os.Build
import androidx.annotation.RequiresApi
import androidx.core.app.NotificationCompat
import androidx.core.app.NotificationManagerCompat
import com.develou.notificaciones_en_android.R

object NotificationUtil {

    @RequiresApi(Build.VERSION_CODES.O)
    fun createChannel(
        context: Context,
        importance: Int,
        name: String,
        description: String,
        showBadges: Boolean
    ) {
        val id = "${context.packageName}.channels.$name"
        val channel = NotificationChannel(id, name, importance).apply {
            this.description = description
            setShowBadge(showBadges)
        }

        val nm: NotificationManager =
            context.getSystemService(Context.NOTIFICATION_SERVICE) as NotificationManager
        nm.createNotificationChannel(channel)
    }

    fun createTutorialNotification(context: Context) {
        val channelId = "${context.packageName}.channels.Tutoriales"
        val largeIcon = BitmapFactory.decodeResource(context.resources, R.drawable.develou)

        val notification = NotificationCompat.Builder(context, channelId)
            .setBadgeIconType(NotificationCompat.BADGE_ICON_SMALL)
            .setSmallIcon(R.drawable.ic_tutorial)
            .setLargeIcon(largeIcon)
            .setContentTitle("¡Nuevo tutorial publicado!")
            .setContentText("Insignias De Notificaciones En Android")
            .addAction(0, "Ver más tarde", null)
            .build()

        showNotification(context, notification, 1)
    }

    fun createReminderNotification(context: Context) {
        val channelId = "${context.packageName}.channels.Recordatorios"

        val notification = NotificationCompat.Builder(context, channelId)
            .setSmallIcon(R.drawable.ic_reminder)
            .setContentTitle("Completar taller de notificaciones")
            .setContentText("Resolver ejercicios faltantes 2 y 7")
            .addAction(0, "Marcar como completada", null)
            .build()

        showNotification(context, notification, 2)
    }

    /**
     * Invoca este método para ver un ejemplo de modificación del número de notificaciones
     * en el menú de las insignas
     */
    fun createNotificationWithBadgeNumber(context: Context) {
        val channelId = "${context.packageName}.channels.Tutoriales"

        val notification = NotificationCompat.Builder(context, channelId)
            .setSmallIcon(R.drawable.ic_tutorial)
            .setContentTitle("¡Nuevo tutorial publicado!")
            .setContentText("Hay 3 nuevos tutoriales")
            .setNumber(3)
            .addAction(0, "Ver más tarde", null)
            .build()

        showNotification(context, notification, 3)
    }

    private fun showNotification(context: Context, notification: Notification, id: Int) {
        with(NotificationManagerCompat.from(context)) {
            notify(id, notification)
        }
    }
}
